package com.link.core.util;

import com.link.core.basic.interceptor.SecurityInterceptor;
import com.link.core.basic.service.BasicServiceException;
import com.link.core.util.redisclient.LinkRedisClient;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class SessionUtil {
   public static void setAttribute(String key, String value, Integer expire) {
      String token = (String)SecurityInterceptor.token.get();
      if (StringUtils.isBlank(token)) {
         throw new BasicServiceException("token不能为空");
      } else if (StringUtils.isBlank(key)) {
         throw new BasicServiceException("key不能为空");
      } else {
         LinkRedisClient jedis = null;

         try {
            jedis = RedisUtil.getJedis();
            String loginInfoMapKey = "login_info_" + token;
            Map<String, String> loginInfoMap = new HashMap();
            loginInfoMap.put("enterprise", "");
            if (!jedis.exists(loginInfoMapKey)) {
               jedis.hmset(loginInfoMapKey, loginInfoMap);
               if (expire != null) {
                  jedis.expire(loginInfoMapKey, expire);
               }
            }

            if (jedis.hmget(loginInfoMapKey, key).size() > 0) {
               jedis.hdel(loginInfoMapKey, key);
            }

            jedis.hset(loginInfoMapKey, key, value);
            jedis.expire(loginInfoMapKey, expire);
         } finally {
            RedisUtil.returnResource(jedis);
         }

      }
   }

   public static void setAttribute(String key, String value) {
      setAttribute(key, value, (Integer)null);
   }

   public static String getAttribute(String key) {
      String token = (String)SecurityInterceptor.token.get();
      if (StringUtils.isBlank(token)) {
         throw new BasicServiceException("token不能为空");
      } else if (StringUtils.isBlank(key)) {
         throw new BasicServiceException("key不能为空");
      } else {
         LinkRedisClient jedis = null;

         List list;
         try {
            jedis = RedisUtil.getJedis();
            String loginInfoKey = "login_info_" + token;
            list = jedis.hmget(loginInfoKey, key);
         } finally {
            RedisUtil.returnResource(jedis);
         }

         return list != null && list.size() != 0 ? (String)list.get(0) : null;
      }
   }

   public static Long getKeyExpires(String key) {
      String value = null;
      String token = (String)SecurityInterceptor.token.get();
      if (StringUtils.isBlank(token)) {
         throw new BasicServiceException("token不能为空");
      } else if (StringUtils.isBlank(key)) {
         throw new BasicServiceException("key不能为空");
      } else {
         LinkRedisClient jedis = null;

         Long ttl;
         try {
            jedis = RedisUtil.getJedis();
            String loginInfoKey = "login_info_" + token;
            ttl = jedis.ttl(loginInfoKey);
         } finally {
            RedisUtil.returnResource(jedis);
         }

         return ttl;
      }
   }

   public static void removeAttribute(String key) {
      String token = (String)SecurityInterceptor.token.get();
      if (StringUtils.isBlank(token)) {
         throw new BasicServiceException("token不能为空");
      } else if (StringUtils.isBlank(key)) {
         throw new BasicServiceException("key不能为空");
      } else {
         LinkRedisClient jedis = null;

         try {
            jedis = RedisUtil.getJedis();
            String loginInfoMapKey = "login_info_" + token;
            if (jedis.exists(loginInfoMapKey) && jedis.hmget(loginInfoMapKey, key).size() > 0) {
               jedis.hdel(loginInfoMapKey, key);
            }
         } finally {
            RedisUtil.returnResource(jedis);
         }

      }
   }
}
